@@ -245,6 +245,9 @@ MISSINGPARAMETER_FLOWID = 'MissingParameter.FlowId'
 # 缺少流程id，请检查后重试。
 MISSINGPARAMETER_FLOWIDS = 'MissingParameter.FlowIds'
 
+# 请传入需要查询的合同或合同组的ID。
+MISSINGPARAMETER_FLOWIDSORFLOWGROUPID = 'MissingParameter.FlowIdsOrFlowGroupId'
+
 # 未指定流程合同信息。
 MISSINGPARAMETER_FLOWINFO = 'MissingParameter.FlowInfo'
 
@@ -281,6 +284,9 @@ OPERATIONDENIED_AUTHTAG = 'OperationDenied.AuthTag'
 # 应用号已被禁止。
 OPERATIONDENIED_BANNEDAPPLICATION = 'OperationDenied.BannedApplication'
 
+# 文件发起静默签未开通白名单。
+OPERATIONDENIED_BYFILESSERVERSIGNFORBID = 'OperationDenied.ByFilesServerSignForbid'
+
 # 只支持下载单个。
 OPERATIONDENIED_DOWNLOADMORETHANONE = 'OperationDenied.DownLoadMoreThanOne'
 
@@ -296,6 +302,9 @@ OPERATIONDENIED_FLOWSTATUSFORBID = 'OperationDenied.FlowStatusForbid'
 # 禁止操作。
 OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'
 
+# 签署人未达到合法年龄。
+OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
+
 # 没有API权限。
 OPERATIONDENIED_NOAPIAUTH = 'OperationDenied.NoApiAuth'
 
